//		Copyright © 1997–1999  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//		$Log: SamhainWindow.cpp,v $
//		Revision 1.1  1999/01/10 09:44:16  jjk
//		Initial revision
//

//		BAlert-like window for the about box.

#include <Application.h>
#include <Button.h>
#include <Message.h>
#include <OS.h>
#include <Point.h>
#include <Rect.h>
#include <View.h>
#include <Window.h>

#include "SamhainWindow.h"

const BPoint kDefaultLocation(100, 100);

const char *const kButtonNames[3] = { "button1", "button2", "button3" };
const int32 kButtonPressed = 'btn ';

static BRect
calcFrame(BRect viewBounds)
{
	viewBounds.OffsetBy(kDefaultLocation);
	return viewBounds;
}

SamhainWindow::SamhainWindow(
	BView *pView, const char *pLabels[3])
:	inherited(calcFrame(pView->Bounds()), "Samhain",
				 B_MODAL_WINDOW,
				 B_NOT_RESIZABLE|B_NOT_CLOSABLE|B_NOT_ZOOMABLE|B_NOT_MINIMIZABLE),
	mButtonSem(B_BAD_SEM_ID),
	mWhichButton(-1)
{
	AddChild(pView);
	
	// Create the buttons.
	BButton *pButtons[3];
	float maxWidth = 0.0;
	float maxHeight = 0.0;

	for (int i = 0; i < 3; ++i) {
		const BRect emptyFrame(B_ORIGIN, B_ORIGIN);
		pButtons[i] = new BButton(emptyFrame, kButtonNames[i], pLabels[i],
										  new BMessage(kButtonPressed + i));
		pButtons[i]->SetTarget(this);
		pButtons[i]->ResizeToPreferred();
		float width, height;
		pButtons[i]->GetPreferredSize(&width, &height);
		if (width > maxWidth) {
			maxWidth = width;
		}
		if (height > maxHeight) {
			maxHeight = height;
		}
	}

	// Size & place the buttons.
	BPoint pos = pView->Bounds().RightBottom() - BPoint(0.0, 1.5 * maxHeight);
	
	for (int i = 2; i >= 0; --i) {
		pButtons[i]->ResizeTo(maxWidth, maxHeight);
		pos.x -= maxWidth + 0.5 * maxHeight;
		pButtons[i]->MoveTo(pos);
		pView->AddChild(pButtons[i]);
	}

	SetDefaultButton(pButtons[2]);
}

SamhainWindow::~SamhainWindow(void)
{
	if (mButtonSem >= B_NO_ERROR) {
		delete_sem(mButtonSem);
	}
}

void
SamhainWindow::MessageReceived(BMessage *pMessage)
{
	switch (pMessage->what) {
	
	case kButtonPressed + 0:
	case kButtonPressed + 1:
	case kButtonPressed + 2:
		// Button pressed.
		mWhichButton = pMessage->what - kButtonPressed;
		if (mButtonSem >= B_NO_ERROR) {
			release_sem(mButtonSem);
		}
		break;
	
	default:
		inherited::MessageReceived(pMessage);
		break;
	}
}

bool
SamhainWindow::QuitRequested(void)
{
	if (mButtonSem >= B_NO_ERROR) {
		release_sem(mButtonSem);
	}
	return true;
}

int32
SamhainWindow::Go(void)
{
	Show();

	int32 result = -1;	
	if (Lock()) {
		mButtonSem = create_sem(0, "SamhainWindow button sem");
		Unlock();
		acquire_sem(mButtonSem);
		result = mWhichButton;
	}

	if (Lock()) {
		Quit();
	}
	
	return result;
}

static char RCSid[] = "$Id: SamhainWindow.cpp,v 1.1 1999/01/10 09:44:16 jjk Exp $";
