//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//		$Log: HorizontalKnot.cpp,v $
//		Revision 1.1  1999/01/10 09:48:19  jjk
//		Initial revision
//

//		A class representing a random horizontally tileable knot.

#include <cstdlib>
#include <Point.h>
#include <Rect.h>
#include <View.h>

#include "KnotSection.h"
#include "RandomKnot.h"
#include "HorizontalKnot.h"

HorizontalKnot::HorizontalKnot(BView *pView)
:	inherited(pView, 6, 4 + rand() % 4, 1)
{
	if (IsValid()) {
		// Set boundary conditions for a horizontal knot.
		int i;
	
		// The left and right borders must match.
		for (i = 1; i < mHeight; ++i) {
			mpSectionCorners[(i+1) * (mWidth+1) - 1] =
				mpSectionCorners[i * (mWidth+1)];
		}
		
		// The top and bottom borders must have horizontal corners.		
		for (i = 0; i <= mWidth; ++i) {
			mpSectionCorners[i] = H;
			mpSectionCorners[mHeight*(mWidth+1) + i] = H;
		}
	}
}

HorizontalKnot::~HorizontalKnot(void)
{
	// empty
}

bool
HorizontalKnot::Draw(void)
{
	if (IsValid()) {
		// Place the knot randomly, then tile it across the screen.
		const BRect bounds = mpView->Bounds();
		const BPoint size = Size();
		BPoint where = LocateKnot();
		for (where.x = 0; where.x < bounds.Width(); where.x += size.x) {
			DrawAt(where);
		}
		mpView->Sync();
		return true;
	}
	return false;
}

static char RCSid[] = "$Id: HorizontalKnot.cpp,v 1.1 1999/01/10 09:48:19 jjk Exp $";
